@@ -1420,6 +1420,15 @@ function getBackupTypeColorJS(type) {
     }
 }
 
+function getBackupTypeIconJS(type) {
+    switch (type) {
+        case 'site': return 'globe';
+        case 'userfiles': return 'folder';
+        case 'database': return 'database';
+        default: return 'file';
+    }
+}
+
 function getStatusColorJS(status) {
     switch (status) {
         case 'completed': return 'success';
